'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

exports.IntegrationType = void 0;
(function (IntegrationType) {
    IntegrationType["PRODUCTION"] = "PRODUCTION";
    IntegrationType["TEST"] = "TEST";
})(exports.IntegrationType || (exports.IntegrationType = {}));
exports.NexiUrl = void 0;
(function (NexiUrl) {
    NexiUrl["PRODUCTION"] = "https://ecommerce.nexi.it/ecomm/XPayBuild/js";
    NexiUrl["TEST"] = "https://int-ecommerce.nexi.it/ecomm/XPayBuild/js";
})(exports.NexiUrl || (exports.NexiUrl = {}));
exports.ERRORS = void 0;
(function (ERRORS) {
    ERRORS["SCRIPT_EXISTS"] = "script already expists";
    ERRORS["SCRIPT_INJECT"] = "Cannot inject Nexi script in HTML document";
    ERRORS["FAILED_TO_LOAD"] = "Failed to load XPay SDK";
    ERRORS["SDK_NOT_AVAILABLE"] = "XPay's sdk is not available";
    ERRORS["XPAY_NOT_VALID"] = "XPay object is not valid";
    ERRORS["PROVIDER_PROPS_CHANGED"] = "Unsupported prop change on XPayProvider. You cannot change its props after setting them";
    ERRORS["USE_XPAY_PROVIDER"] = "Error, useXPay must be used in a component wrapped in XPayProvider";
    ERRORS["MISSING_NONCE_HANDLER"] = "onNonceEvent fired but custom handler is missing";
    ERRORS["MISSING_PAYMENT_RESULT_HANDLER"] = "PaymentResult fired but custom handler is missing";
})(exports.ERRORS || (exports.ERRORS = {}));
exports.Languages = void 0;
(function (Languages) {
    Languages["ITA"] = "ITA";
    Languages["ENG"] = "ENG";
    Languages["SPA"] = "SPA";
    Languages["FRA"] = "FRA";
    Languages["GER"] = "GER";
    Languages["JPN"] = "JPN";
    Languages["CHI"] = "CHI";
    Languages["ARA"] = "ARA";
    Languages["RUS"] = "RUS";
    Languages["POR"] = "POR";
})(exports.Languages || (exports.Languages = {}));
exports.CardTypes = void 0;
(function (CardTypes) {
    CardTypes["CARD"] = "card";
    CardTypes["SPLIT"] = "split";
})(exports.CardTypes || (exports.CardTypes = {}));

var usePrevious = function (value) {
    var ref = React.useRef(value);
    React.useEffect(function () {
        ref.current = value;
    }, [value]);
    return ref.current;
};

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

var isPromise = function (raw) {
    return isUnknownObject(raw) && typeof raw.then === "function";
};
var isUnknownObject = function (raw) {
    return raw !== null && typeof raw === "object";
};
/**
 * Checks if object is a valid XPay object, checking its `createNonce` property
**/
var isXPay = function (x) {
    return (x !== null &&
        typeof x === "object" &&
        Object.prototype.hasOwnProperty.call(x, "createNonce"));
};

/**
 * Builds initial XPay config object
 **/
function buildConfig(apiKey, isProduction, order, XPay, customConfig) {
    var config = {
        baseConfig: {
            apiKey: apiKey,
            enviroment: isProduction
                ? XPay.Environments.PROD
                : XPay.Environments.INTEG,
        },
        paymentParams: {
            amount: order.amount,
            transactionId: order.transactionId,
            currency: order.currency,
            timeStamp: order.timeStamp,
            mac: order.mac,
            url: order.url,
            urlBack: order.urlBack,
        },
        customParams: {},
        language: XPay.LANGUAGE.ITA,
    };
    var newConfig = __assign(__assign({}, config), (customConfig && __assign(__assign(__assign(__assign(__assign({}, (customConfig.main && __assign({}, customConfig.main))), (customConfig.baseConfig && {
        baseConfig: __assign(__assign({}, config.baseConfig), customConfig.baseConfig),
    })), (customConfig.paymentParams && {
        paymentParams: __assign(__assign({}, config.paymentParams), customConfig.paymentParams),
    })), (customConfig.customParams && {
        customParams: __assign(__assign({}, config.customParams), customConfig.customParams),
    })), (customConfig.language && {
        language: XPay.LANGUAGE[customConfig.language],
    }))));
    return newConfig;
}
var validateXPay = function (xpay) {
    if (xpay === null || isXPay(xpay)) {
        return xpay;
    }
    throw new Error(exports.ERRORS.XPAY_NOT_VALID);
};
/**
 * Parses loaded XPay data from prop
 * XPay data can be:
 * - a `pending promise` (tag `async`)
 * - `null` (SSR, tag `empty`)
 * - an `object` (promise fulfilled, tag `sync`)
 **/
var parseXPayProp = function (raw) {
    if (isPromise(raw)) {
        return {
            tag: "async",
            sdkPromise: Promise.resolve(raw).then(validateXPay),
        };
    }
    var sdk = validateXPay(raw);
    if (sdk === null) {
        return { tag: "empty" };
    }
    return { tag: "sync", sdk: sdk };
};

var XPayContext = React.createContext(null);
var XPayProvider = function (_a) {
    var sdk = _a.sdk, order = _a.order, apiKey = _a.apiKey, _b = _a.isProduction, isProduction = _b === void 0 ? false : _b, xpayReadyHandler = _a.xpayReadyHandler, paymentStartedHandler = _a.paymentStartedHandler, nonceHandler = _a.nonceHandler, paymentResultHandler = _a.paymentResultHandler, _c = _a.customConfig, customConfig = _c === void 0 ? null : _c, _d = _a.secure, secure = _d === void 0 ? true : _d, children = _a.children;
    var parsed = parseXPayProp(sdk);
    var _e = React.useState(function () { return ({
        sdk: parsed.tag === "sync" ? parsed.sdk : null,
    }); }), ctx = _e[0], setContext = _e[1];
    var _f = React.useState(false), initialConfig = _f[0], setInitialConfig = _f[1];
    React.useEffect(function () {
        var isMounted = true;
        var updateCtx = function (sdk) {
            setContext(function (ctx) {
                if (ctx.sdk)
                    return ctx;
                return {
                    sdk: sdk,
                };
            });
        };
        // handle `sdk promise`
        if (parsed.tag === "async" && !ctx.sdk) {
            parsed.sdkPromise.then(function (s) {
                if (sdk && isMounted) {
                    updateCtx(s);
                }
            });
        }
        else if (parsed.tag === "sync" && !ctx.sdk) {
            // handle transiction from `sdk null` to `object` (fulfilledPromise)
            updateCtx(parsed.sdk);
        }
        return function () {
            isMounted = false;
        };
    }, [parsed]);
    /**
     * Init XPay Build SDK and set payment config
     **/
    React.useEffect(function () {
        if (!ctx.sdk) {
            return;
        }
        var XPay = window.XPay;
        if (!XPay) {
            return;
        }
        // init sdk
        XPay.init();
        var config = buildConfig(apiKey, isProduction, order, XPay, customConfig);
        XPay.setConfig(config);
        /**
         * Sets initialConfig to true
         * Other components will mount nexi's iframes on DOM only
         * if this flag is true
         **/
        setInitialConfig(true);
        // Handle 3D secure
        if (secure) {
            XPay.setInformazioniSicurezza({});
        }
        return function () {
            setInitialConfig(false);
        };
    }, [ctx.sdk]);
    /**
     * Detect props changes
     **/
    var prevXPay = usePrevious(sdk);
    React.useEffect(function () {
        if (prevXPay !== null && prevXPay !== sdk) {
            console.warn(exports.ERRORS.PROVIDER_PROPS_CHANGED);
        }
    }, [prevXPay, sdk]);
    /**
     * Set event listeners with custom callbacks, if provided
     **/
    React.useEffect(function () {
        // library ready
        var onXPayReady = function (e) {
            if (xpayReadyHandler) {
                return xpayReadyHandler(e);
            }
            console.log("XPay Build sdk ready:", e);
        };
        // detects click on APM
        var onPaymentStartedHandler = function (e) {
            if (paymentStartedHandler) {
                return paymentStartedHandler(e);
            }
            console.log("PaymentStarted:", e);
        };
        // card
        var onNonceEvent = function (e) {
            if (!nonceHandler) {
                console.warn("".concat(exports.ERRORS.MISSING_NONCE_HANDLER), e.detail);
                return;
            }
            return nonceHandler(e.detail);
        };
        // detects apm results (e.detail.tipoTransazione === 'PAYPAL')
        var onPaymentResult = function (e) {
            if (!paymentResultHandler) {
                console.log("".concat(exports.ERRORS.MISSING_PAYMENT_RESULT_HANDLER), e.detail);
                return;
            }
            return paymentResultHandler(e.detail);
        };
        window.addEventListener("XPay_Ready", onXPayReady);
        window.addEventListener("XPay_Nonce", onNonceEvent);
        window.addEventListener("XPay_Payment_Started", onPaymentStartedHandler);
        window.addEventListener("XPay_Payment_Result", onPaymentResult);
        return function () {
            window.removeEventListener("XPay_Ready", onXPayReady);
            window.removeEventListener("XPay_Nonce", onNonceEvent);
            window.removeEventListener("XPay_Payment_Started", onPaymentStartedHandler);
            window.removeEventListener("XPay_Payment_Result", onPaymentResult);
        };
    }, []);
    return (React__default["default"].createElement(XPayContext.Provider, { value: { ctx: ctx, initialConfig: initialConfig } }, children));
};
XPayProvider.displayName = "XPayProvider";
/**
 * Hooks
 **/
var useXPay = function () {
    var ctx = React.useContext(XPayContext);
    if (!ctx) {
        console.warn(exports.ERRORS.USE_XPAY_PROVIDER);
        return false;
    }
    return ctx;
};

/**
 * @prop showErrors
 * @prop cardErrorHandler
 **/
var XPayCard = React.forwardRef(function (_a, ref) {
    var _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u, _v, _w, _x, _y, _z, _0;
    var _1 = _a.cardType, cardType = _1 === void 0 ? exports.CardTypes.CARD : _1, _2 = _a.style, style = _2 === void 0 ? null : _2, _3 = _a.styleWrapper, styleWrapper = _3 === void 0 ? null : _3, _4 = _a.classNameWrapper, classNameWrapper = _4 === void 0 ? null : _4, _5 = _a.styleErrors, styleErrors = _5 === void 0 ? null : _5, _6 = _a.showErrors, showErrors = _6 === void 0 ? true : _6, _7 = _a.styleSplitted, styleSplitted = _7 === void 0 ? null : _7, _8 = _a.labelPan, labelPan = _8 === void 0 ? null : _8, _9 = _a.labelExpiry, labelExpiry = _9 === void 0 ? null : _9, _10 = _a.labelCVC, labelCVC = _10 === void 0 ? null : _10, _11 = _a.cardErrorHandler, cardErrorHandler = _11 === void 0 ? null : _11;
    var _12 = React.useState(null), cardErrors = _12[0], setCardErrors = _12[1];
    var _13 = React.useState(false), isMounted = _13[0], setIsMounted = _13[1];
    var XPayContext = useXPay();
    var initRef = React.useRef(false);
    var cardRef = React.useRef(null);
    React.useEffect(function () {
        if (!isMounted) {
            setIsMounted(true);
        }
        return function () { return setIsMounted(false); };
    }, []);
    React.useEffect(function () {
        if (!isMounted ||
            !window.XPay ||
            !XPayContext.initialConfig ||
            !initRef ||
            !!(initRef === null || initRef === void 0 ? void 0 : initRef.current)) {
            return;
        }
        initRef.current = true;
        var carddiv = createCardWrapper(style, cardType);
        cardRef.current = carddiv;
        if (cardType === exports.CardTypes.CARD) {
            carddiv.mount("react-xpay-card");
        }
        else {
            carddiv.mount("react-xpay-pan", "react-xpay-expiry", "react-xpay-cvc");
        }
    }, [isMounted, XPayContext.initialConfig]);
    React.useEffect(function () {
        var onCardError = function (e) {
            console.log(e);
            if (cardErrorHandler) {
                if (showErrors) {
                    setCardErrors(function (prev) { return e.detail.errorMessage || null; });
                }
                cardErrorHandler(e.detail.errorMessage || null);
            }
        };
        window.addEventListener("XPay_Card_Error", onCardError);
        return function () {
            window.removeEventListener("XPay_Card_Error", onCardError);
        };
    }, []);
    var createNonce = function () {
        window.XPay.createNonce("payment-form", cardRef.current);
    };
    React.useImperativeHandle(ref, function () { return ({ createNonce: createNonce }); }, []);
    return (React__default["default"].createElement("div", null,
        React__default["default"].createElement("div", __assign({ id: "react-xpay-card", ref: cardRef }, (styleWrapper && { style: styleWrapper }), (classNameWrapper && { className: classNameWrapper }))),
        cardType === exports.CardTypes.SPLIT && (React__default["default"].createElement("div", __assign({}, ((styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.wrapper) && {
            style: styleSplitted.wrapper,
        }), ((styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.classNameWrapper) && {
            className: styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.classNameWrapper,
        })),
            React__default["default"].createElement("div", __assign({}, (((_b = styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.pan) === null || _b === void 0 ? void 0 : _b.wrapper) && {
                style: (_c = styleSplitted.pan) === null || _c === void 0 ? void 0 : _c.wrapper,
            }), (((_d = styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.pan) === null || _d === void 0 ? void 0 : _d.classNameWrapper) && {
                className: (_e = styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.pan) === null || _e === void 0 ? void 0 : _e.classNameWrapper,
            })),
                labelPan && labelPan,
                React__default["default"].createElement("div", __assign({ id: "react-xpay-pan" }, (((_f = styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.pan) === null || _f === void 0 ? void 0 : _f.input) && {
                    style: (_g = styleSplitted.pan) === null || _g === void 0 ? void 0 : _g.input,
                }), (((_h = styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.pan) === null || _h === void 0 ? void 0 : _h.classNameInput) && {
                    className: (_j = styleSplitted.pan) === null || _j === void 0 ? void 0 : _j.classNameInput,
                })))),
            React__default["default"].createElement("div", __assign({}, (((_k = styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.expiry) === null || _k === void 0 ? void 0 : _k.wrapper) && {
                style: (_l = styleSplitted.expiry) === null || _l === void 0 ? void 0 : _l.wrapper,
            }), (((_m = styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.expiry) === null || _m === void 0 ? void 0 : _m.classNameWrapper) && {
                className: (_o = styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.expiry) === null || _o === void 0 ? void 0 : _o.classNameWrapper,
            })),
                labelExpiry && labelExpiry,
                React__default["default"].createElement("div", __assign({ id: "react-xpay-expiry" }, (((_p = styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.expiry) === null || _p === void 0 ? void 0 : _p.input) && {
                    style: (_q = styleSplitted.expiry) === null || _q === void 0 ? void 0 : _q.input,
                }), (((_r = styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.expiry) === null || _r === void 0 ? void 0 : _r.classNameInput) && {
                    className: (_s = styleSplitted.expiry) === null || _s === void 0 ? void 0 : _s.classNameInput,
                })))),
            React__default["default"].createElement("div", __assign({}, (((_t = styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.cvc) === null || _t === void 0 ? void 0 : _t.wrapper) && {
                style: (_u = styleSplitted.cvc) === null || _u === void 0 ? void 0 : _u.wrapper,
            }), (((_v = styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.cvc) === null || _v === void 0 ? void 0 : _v.classNameWrapper) && {
                className: (_w = styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.cvc) === null || _w === void 0 ? void 0 : _w.classNameWrapper,
            })),
                labelCVC && labelCVC,
                React__default["default"].createElement("div", __assign({ id: "react-xpay-cvc" }, (((_x = styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.cvc) === null || _x === void 0 ? void 0 : _x.input) && {
                    style: (_y = styleSplitted.cvc) === null || _y === void 0 ? void 0 : _y.input,
                }), (((_z = styleSplitted === null || styleSplitted === void 0 ? void 0 : styleSplitted.cvc) === null || _z === void 0 ? void 0 : _z.classNameInput) && {
                    className: (_0 = styleSplitted.cvc) === null || _0 === void 0 ? void 0 : _0.classNameInput,
                })))))),
        showErrors && cardErrors && (React__default["default"].createElement("div", __assign({}, (styleErrors && { style: styleErrors })), cardErrors))));
});
var useCard = function () {
    return {
        pay: function (cardRef) { return cardRef.current.createNonce(); },
    };
};
var createCardWrapper = function (style, cardType) {
    if (cardType === exports.CardTypes.CARD) {
        return style
            ? window.XPay.create(window.XPay.OPERATION_TYPES.CARD, style)
            : window.XPay.create(window.XPay.OPERATION_TYPES.CARD);
    }
    return style
        ? window.XPay.create(window.XPay.OPERATION_TYPES.SPLIT_CARD, style)
        : window.XPay.create(window.XPay.OPERATION_TYPES.SPLIT_CARD);
};

var XPayAPM = function (_a) {
    var _b = _a.paymentMethodName, paymentMethodName = _b === void 0 ? undefined : _b; _a.style;
    var _d = React.useState(false), isMounted = _d[0], setIsMounted = _d[1];
    var initRef = React.useRef(false);
    var XPayContext = useXPay();
    React.useEffect(function () {
        if (!isMounted) {
            setIsMounted(true);
        }
        return function () { return setIsMounted(false); };
    }, []);
    React.useEffect(function () {
        if (!isMounted ||
            !window.XPay ||
            !XPayContext.initialConfig ||
            !initRef ||
            !!(initRef === null || initRef === void 0 ? void 0 : initRef.current)) {
            return;
        }
        initRef.current = true;
        var btn = window.XPay.create(window.XPay.OPERATION_TYPES.PAYMENT_BUTTON, getNexiPaymentMethods(paymentMethodName));
        btn.mount(getDivName(paymentMethodName));
    }, [isMounted, XPayContext.initialConfig]);
    return React__default["default"].createElement("div", { id: getDivName(paymentMethodName) });
};
function getNexiPaymentMethods(n) {
    return n ? (Array.isArray(n) ? n : [n]) : [];
}
function getDivName(n) {
    return "react-XPay-".concat(n ? (Array.isArray(n) ? n.join("--") : n) : "APMS");
}

var XPayPromise = null;
var loadScript = function (params) {
    // load nexi sdk once
    if (XPayPromise !== null) {
        return XPayPromise;
    }
    XPayPromise = new Promise(function (resolve, reject) {
        // handle ssr
        if (typeof window === "undefined") {
            resolve(null);
            return;
        }
        if (window.XPay) {
            console.warn(exports.ERRORS.SCRIPT_EXISTS);
        }
        if (window.XPay) {
            resolve(window.XPay);
            return;
        }
        try {
            var script = findScript(params);
            if (script) {
                console.warn(exports.ERRORS.SCRIPT_EXISTS);
            }
            else if (!script) {
                script = injectScript(params);
            }
            script.addEventListener("load", function () {
                if (window.XPay) {
                    console.log("XPay script loaded");
                    resolve(window.XPay);
                }
                else {
                    console.warn(exports.ERRORS.SDK_NOT_AVAILABLE);
                    reject(new Error(exports.ERRORS.SDK_NOT_AVAILABLE));
                }
            });
            script.addEventListener("error", function () {
                console.warn(exports.ERRORS.FAILED_TO_LOAD);
                reject(new Error(exports.ERRORS.FAILED_TO_LOAD));
            });
        }
        catch (error) {
            console.warn(error);
            reject(error);
            return;
        }
    });
    return XPayPromise;
};
var findScript = function (params) {
    var nexiurl = getNexiUrl(params, true);
    var scripts = document.querySelectorAll("script[src^=\"".concat(nexiurl, "\"]"));
    for (var i = 0; i < scripts.length; i++) {
        var script = scripts[i];
        if (!script.src.includes(nexiurl)) {
            continue;
        }
        return script;
    }
    return null;
};
var injectScript = function (params) {
    var script = document.createElement("script");
    script.src = "".concat(getNexiUrl(params, false));
    var target = document.head || document.body;
    if (!target) {
        throw new Error(exports.ERRORS.SCRIPT_INJECT);
    }
    target.appendChild(script);
    return script;
};
var getNexiUrl = function (_a, short) {
    var alias = _a.alias, isProduction = _a.isProduction, url = _a.url;
    if (short === void 0) { short = false; }
    if (url) {
        return url + alias;
    }
    if (short) {
        return isProduction ? exports.NexiUrl.PRODUCTION : exports.NexiUrl.TEST;
    }
    return isProduction
        ? exports.NexiUrl.PRODUCTION + "?alias=" + alias
        : exports.NexiUrl.TEST + "?alias=" + alias;
};

var loadSdkCalled = false;
var loadXPay = function (args) {
    if (loadSdkCalled) {
        console.warn("Library already initialized");
    }
    loadSdkCalled = true;
    return loadScript(args).then(function (xpay) { return initXPay(xpay, args); });
};
var initXPay = function (xpay, args) {
    if (xpay === null) {
        return null;
    }
    var XPay = __assign(__assign({}, xpay), { argsAPIKEY: args.alias, argsENVIRONMENT: args.isProduction });
    return XPay;
};

exports.XPayAPM = XPayAPM;
exports.XPayCard = XPayCard;
exports.XPayContext = XPayContext;
exports.XPayProvider = XPayProvider;
exports.initXPay = initXPay;
exports.loadXPay = loadXPay;
exports.useCard = useCard;
exports.useXPay = useXPay;
//# sourceMappingURL=index.js.map
